@@ -24,6 +24,7 @@
 #include "MediaInfo/Audio/File_Dts.h"
 #include "ZenLib/Utils.h"
 #include "ZenLib/BitStream.h"
+#include "MediaInfo/TimeCode.h"
 #include "MediaInfo/MediaInfo_Config_MediaInfo.h"
 #if MEDIAINFO_EVENTS
     #include "MediaInfo/MediaInfo_Events.h"
@@ -40,6 +41,46 @@ namespace MediaInfoLib
 // Infos
 //***************************************************************************
 
+//---------------------------------------------------------------------------
+static constexpr int64u CHUNK_AUPR_HDR=0x415550522D484452LL;
+static constexpr int64u CHUNK_BUILDVER=0x4255494C44564552LL;
+static constexpr int64u CHUNK_CORESSMD=0x434F524553534D44LL;
+static constexpr int64u CHUNK_DTSHDHDR=0x4454534844484452LL;
+static constexpr int64u CHUNK_EXTSS_MD=0x45585453535F4D44LL;
+static constexpr int64u CHUNK_FILEINFO=0x46494C45494E464FLL;
+static constexpr int64u CHUNK_TIMECODE=0x54494D45434F4445LL;
+static constexpr int64u CHUNK_STRMDATA=0x5354524D44415441LL;
+
+//---------------------------------------------------------------------------
+void Merge_FillTimeCode(File__Analyze& In, const string& Prefix, const TimeCode& TC_Time, float FramesPerSecondF, bool DropFrame, TimeCode::rounding Rounding=TimeCode::Nearest, int32u Frequency=0);
+
+//---------------------------------------------------------------------------
+static const float TC_Frame_Rate_Table[]=
+{
+    // Value 0 means "not indicated"
+    24/1.001,
+    24,
+    25,
+    30/1.001, // Drop
+    30/1.001,
+    30, // Drop
+    30,
+};
+static constexpr size_t TC_Frame_Rate_Table_Size=sizeof(TC_Frame_Rate_Table)/sizeof(*TC_Frame_Rate_Table);
+static bool TC_Frame_Rate_IsDrop(int8u Value)
+{
+    return Value==4 || Value==6;
+}
+
+//---------------------------------------------------------------------------
+static const int16u DTS_HD_RefClockCode[]=
+{
+    32000,
+    44100,
+    48000,
+};
+static constexpr size_t DTS_HD_RefClockCode_Size=sizeof(DTS_HD_RefClockCode)/sizeof(*DTS_HD_RefClockCode);
+
 //---------------------------------------------------------------------------
 static const int16u CRC_CCIT_Table[256]=
 {
@@ -197,15 +238,6 @@ static const char* DTS_ExtensionAudioDescriptor[]=
     "",
 };
 
-//---------------------------------------------------------------------------
-static const char* DTS_HD_RefClockCode[]=
-{
-    "1/32000",
-    "1/44100",
-    "1/48000",
-    "",
-};
-
 //---------------------------------------------------------------------------
 std::string DTS_HD_SpeakerActivityMask (int16u SpeakerActivityMask, bool AddCs=false, bool AddLrsRrs=false)
 {
@@ -488,8 +520,8 @@ static size_t DTS_Extension_Index_Get(int32u SyncWord)
 {
     for (size_t i=0; i<Ext_Max; i++)
         if (SyncWord==DTS_Extension_Mapping[i])
-            return i+1;
-    return 0;
+            return i;
+    return (size_t)-1;
 }
 
 //***************************************************************************
@@ -498,7 +530,7 @@ static size_t DTS_Extension_Index_Get(int32u SyncWord)
 
 //---------------------------------------------------------------------------
 File_Dts::File_Dts()
-:File__Analyze()
+:File_Dts_Common()
 {
     //Configuration
     ParserName="Dts";
@@ -865,7 +897,7 @@ void File_Dts::Streams_Fill()
     Fill(Stream_Audio, 0, Audio_SamplingRate, LegacyStreamDisplay?Data[SamplingRate].Read():Data[SamplingRate].Read(0));
     Fill(Stream_Audio, 0, Audio_SamplesPerFrame, LegacyStreamDisplay?Data[SamplesPerFrame].Read():Data[SamplesPerFrame].Read(0));
     Fill(Stream_Audio, 0, Audio_BitRate, LegacyStreamDisplay?Data[BitRate].Read():(Data[BitRate].Read(0)==__T("Unknown")?Ztring():Data[BitRate].Read(0)));
-    Fill(Stream_Audio, 0, Audio_BitRate_Mode, LegacyStreamDisplay?Data[BitRate_Mode].Read():Data[BitRate_Mode].Read(0));
+    Fill(Stream_Audio, 0, Audio_BitRate_Mode, LegacyStreamDisplay?Data[BitRate_Mode].Read():Data[BitRate_Mode].Read(0), true);
     Fill(Stream_General, 0, General_OverallBitRate_Mode, Retrieve(Stream_Audio, 0, Audio_BitRate_Mode));
     Fill(Stream_Audio, 0, Audio_Compression_Mode, LegacyStreamDisplay?Data[Compression_Mode].Read():Data[Compression_Mode].Read(0), true);
 
@@ -895,7 +927,7 @@ void File_Dts::Streams_Finish()
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-bool File_Dts::FileHeader_Begin()
+bool File_Dts_Common::FileHeader_Begin()
 {
     //Must have enough buffer for having header
     if (Buffer_Size<4)
@@ -917,6 +949,245 @@ bool File_Dts::FileHeader_Begin()
     return true;
 }
 
+//---------------------------------------------------------------------------
+void File_Dts_Common::FileHeader_Parse()
+{
+    //DTSHDHDR header
+    //https://www.atsc.org/wp-content/uploads/2015/03/Non-Real-Time-Content-Delivery.pdf
+    if (IsSub || CC8(Buffer)!=CHUNK_DTSHDHDR || CC4(Buffer+8))
+        return;
+    int64u StreamSize=-1;
+    int16u Bitw_Stream_Metadata;
+    bool Header_Parsed=false;
+    int64u Num_Samples_Orig_Audio_At_Max_Fs=0;
+    int32u Num_Frames_Total, TimeStamp, Max_Sample_Rate_Hz=0, Ext_Ss_Avg_Bit_Rate_Kbps=0, Ext_Ss_Peak_Bit_Rate_Kbps=0;
+    int16u Core_Ss_Bit_Rate_Kbps=0, Samples_Per_Frame_At_Max_Fs=0, Codec_Delay_At_Max_Fs=0;
+    int8u RefClockCode, TC_Frame_Rate=-1;
+    while (StreamSize==-1 && Element_Size-Element_Offset>=16)
+    {
+        int64u Name, Size;
+        Element_Begin1("Element");
+        Element_Begin1("Header");
+        Get_C8 (Name,                                           "Name");
+        Get_B8 (Size,                                           "Size");
+        Element_End0();
+        Ztring ToShow;
+        for (int i=0; i<8; i++)
+            ToShow.append(1, (ZenLib::Char)((Name>>(56-i*8)))&0xFF);
+        Element_Name(ToShow);
+        if (Name!=CHUNK_STRMDATA && Size>Element_Size-Element_Offset)
+        {
+            Element_End0();
+            Element_WaitForMoreData();
+            return;
+        }
+        auto End=Element_Offset+Size;
+        switch (Name)
+        {
+            case CHUNK_AUPR_HDR:
+            {
+                int16u Bitw_Aupres_Metadata;
+                Skip_B1(                                        "Audio_Pres_Index");
+                Get_B2 (Bitw_Aupres_Metadata,                   "Bitw_Aupres_Metadata");
+                Skip_Flags(Bitw_Aupres_Metadata, 3,             "Presence of a LBR coding componen");
+                Skip_Flags(Bitw_Aupres_Metadata, 2,             "Presence of a lossless coding component");
+                Skip_Flags(Bitw_Aupres_Metadata, 1,             "Location of a backward compatible core coding component");
+                Skip_Flags(Bitw_Aupres_Metadata, 0,             "Presence of a backward compatible core coding component");
+                Get_B3 (Max_Sample_Rate_Hz,                     "Max_Sample_Rate_Hz");
+                Get_B4 (Num_Frames_Total,                       "Num_Frames_Total");
+                Get_B2 (Samples_Per_Frame_At_Max_Fs,            "Samples_Per_Frame_At_Max_Fs");
+                Get_B5 (Num_Samples_Orig_Audio_At_Max_Fs,       "Num_Samples_Orig_Audio_At_Max_Fs");
+                Skip_B2(                                        "Channel_Mask");
+                Get_B2 (Codec_Delay_At_Max_Fs,                  "Codec_Delay_At_Max_Fs");
+                if ((Bitw_Aupres_Metadata&3)==3)
+                {
+                    Skip_B3(                                    "BC_Core_Max_Sample_Rate_Hz");
+                    Skip_B2(                                    "BC_Core_Bit_Rate_Kbps");
+                    Skip_B2(                                    "BC_Core_Channel_Mask");
+                }
+                if (Bitw_Aupres_Metadata&4)
+                {
+                    Skip_B1(                                    "LSB_Trim_Percent");
+                }
+                break;
+            }
+            case CHUNK_CORESSMD:
+            {
+                Skip_B3(                                        "Core_Ss_Max_Sample_Rate_Hz");
+                Get_B2 (Core_Ss_Bit_Rate_Kbps,                  "Core_Ss_Bit_Rate_Kbps");
+                Skip_B2(                                        "Core_Ss_Channel_Mask");
+                Skip_B4(                                        "Core_Ss_Frame_Payload_In_Bytes");
+                break;
+            }
+            case CHUNK_DTSHDHDR:
+            {
+                Skip_B4(                                        "Hdr_Version");
+                Get_B1 (RefClockCode,                           "Time_Code RefClockCode");
+                RefClockCode>>=6;
+                Param_Info1C(RefClockCode<DTS_HD_RefClockCode_Size, DTS_HD_RefClockCode[RefClockCode]);
+                Get_B4 (TimeStamp,                              "Time_Code TimeStamp");
+                Get_B1 (TC_Frame_Rate,                          "TC_Frame_Rate"); Param_Info1C(TC_Frame_Rate && TC_Frame_Rate<TC_Frame_Rate_Table_Size-1, TC_Frame_Rate_Table[TC_Frame_Rate-1]);
+                Get_B2 (Bitw_Stream_Metadata,                   "Bitw_Stream_Metadata");
+                Skip_Flags(Bitw_Stream_Metadata, 4,             "Presence of an extension sub-stream(s)");
+                Skip_Flags(Bitw_Stream_Metadata, 3,             "Presence of a core sub-stream");
+                Skip_Flags(Bitw_Stream_Metadata, 2,             "Navigation table");
+                Skip_Flags(Bitw_Stream_Metadata, 1,             "Peak bit rate smoothing");
+                Skip_Flags(Bitw_Stream_Metadata, 0,             "Variable bit-rate");
+                Skip_B1(                                        "Num_Audio_Presentations");
+                Skip_B1(                                        "Number_Of_Ext_Sub_Streams");
+                break;
+            }
+            case CHUNK_EXTSS_MD:
+            {
+                Get_B3 (Ext_Ss_Avg_Bit_Rate_Kbps,               "Ext_Ss_Avg_Bit_Rate_Kbps");
+                if (Bitw_Stream_Metadata&1)
+                {
+                    Get_B3 (Ext_Ss_Peak_Bit_Rate_Kbps,          "Ext_Ss_Peak_Bit_Rate_Kbps");
+                    Skip_B2(                                    "Pbr_Smooth_Buff_Size_Kb");
+                }
+                else
+                {
+                    Skip_B4(                                    "Ext_Ss_Frame_Payload_In_Bytes");
+
+                }
+                break;
+            }
+            case CHUNK_STRMDATA:
+                StreamSize=Size;
+                break;
+        }
+        if (Name!=CHUNK_STRMDATA)
+        {
+            Skip_XX(End-Element_Offset,                         End-Element_Offset<=3?"Dword_Align":"(Unknown)");
+            Element_Offset=End;
+        }
+        Element_End0();
+    }
+    if (StreamSize==-1)
+    {
+        Element_WaitForMoreData();
+        return;
+    }
+
+    FILLING_BEGIN()
+        Fill(Stream_Audio, 0, Audio_BitRate_Mode, (Bitw_Stream_Metadata&1)?"VBR":"CBR");
+        if (RefClockCode<DTS_HD_RefClockCode_Size && TC_Frame_Rate)
+        {
+            auto RefClock=DTS_HD_RefClockCode[RefClockCode];
+            TimeCode TC(TimeStamp, RefClock-1, TimeCode::Timed());
+            Fill(Stream_Audio, 0, Audio_Delay, TC.ToSeconds()*1000, 3);
+            Merge_FillTimeCode(*this, "TimeCode", TC, (TC_Frame_Rate<TC_Frame_Rate_Table_Size-1)?TC_Frame_Rate_Table[TC_Frame_Rate-1]:0, TC_Frame_Rate_IsDrop(TC_Frame_Rate), TimeCode::Floor, RefClock);
+        }
+        if (Num_Frames_Total)
+            Fill(Stream_Audio, 0, Audio_FrameCount, Num_Frames_Total);
+        if (Max_Sample_Rate_Hz && Samples_Per_Frame_At_Max_Fs && Num_Samples_Orig_Audio_At_Max_Fs)
+        {
+            int64u SamplingCount=Num_Samples_Orig_Audio_At_Max_Fs;
+            if (Codec_Delay_At_Max_Fs>=Samples_Per_Frame_At_Max_Fs)
+                SamplingCount+=Codec_Delay_At_Max_Fs; // If less, we guess it is a delay inside the frame and first samples should be discarded, else it is complete frames, so need to add to sample count as the frames are decoded
+            Fill(Stream_Audio, 0, Audio_SamplingCount, SamplingCount);
+        }
+        int32u BitRate_Nominal=Core_Ss_Bit_Rate_Kbps+Ext_Ss_Avg_Bit_Rate_Kbps;
+        if (BitRate_Nominal)
+        {
+            BitRate_Nominal*=1000;
+            Fill(Stream_General, 0, General_OverallBitRate, BitRate_Nominal);
+            Fill(Stream_Audio, 0, Audio_BitRate_Nominal, BitRate_Nominal);
+        }
+        if (Ext_Ss_Peak_Bit_Rate_Kbps)
+        {
+            int32u BitRate_Maximum=Core_Ss_Bit_Rate_Kbps+Ext_Ss_Peak_Bit_Rate_Kbps;
+            BitRate_Maximum*=1000;
+            Fill(Stream_General, 0, General_OverallBitRate_Maximum, BitRate_Maximum);
+            Fill(Stream_Audio, 0, Audio_BitRate_Maximum, BitRate_Maximum);
+        }
+        Fill(Stream_Audio, 0, Audio_StreamSize, StreamSize);
+
+        Stream_Offset_Max=File_Offset+Element_Offset+StreamSize;
+    FILLING_END()
+}
+
+
+//***************************************************************************
+// Buffer - Gobal
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+bool File_Dts_Common::Header_Begin()
+{
+    if (Stream_Offset_Max==-1 || File_Offset+Buffer_Offset!=Stream_Offset_Max || File_Size==-1)
+        return true;
+
+    //Handling DTSHDHDR footer
+    if (File_Offset+Buffer_Size<File_Size)
+    {
+        return false; //Wait for more data
+    }
+    Element_Begin1("File Footer");
+    while (Element_Size-Element_Offset>=16)
+    {
+        int64u Name, Size;
+        Element_Begin1("Element");
+        Element_Begin1("Header");
+        Get_C8 (Name,                                           "Name");
+        Get_B8 (Size,                                           "Size");
+        Element_End0();
+        Ztring ToShow;
+        for (int i=0; i<8; i++)
+            ToShow.append(1, (ZenLib::Char)((Name>>(56-i*8)))&0xFF);
+        Element_Name(ToShow);
+        auto End=Element_Offset+Size;
+        switch (Name)
+        {
+            case CHUNK_BUILDVER:
+            {
+                size_t Element_Offset_End=(size_t)Element_Offset;
+                while (Element_Offset_End<End && Buffer[Buffer_Offset+Element_Offset_End])
+                    Element_Offset_End++;
+                Skip_UTF8(Element_Offset_End-Element_Offset,    "Description");
+                if (Element_Offset<End)
+                    Element_Offset++; //Null termination
+                break;
+            }
+            case CHUNK_FILEINFO:
+            {
+                if (!Size)
+                    break;
+                int8u FILEINFO_Text_Byte_Size;
+                Get_B1 (FILEINFO_Text_Byte_Size,                "FILEINFO_Text_Byte_Size");
+                if (FILEINFO_Text_Byte_Size && FILEINFO_Text_Byte_Size<Size-1)
+                {
+                    Skip_UTF8(FILEINFO_Text_Byte_Size-1,        "Description");
+                    Element_Offset++; //Null termination
+                }
+                else
+                    Skip_XX(End-Element_Offset,                 "(Unknown)");
+                break;
+            }
+            case CHUNK_TIMECODE:
+            {
+                int64u Start_Sample, Reference_Sample;
+                int32u Timecode_Clock, Start_Residual, Reference_Residual;
+                int8u Timecode_Frame_Rate;
+                Get_B4 (Timecode_Clock,                         "Timecode Clock");
+                Get_B1 (Timecode_Frame_Rate,                    "Timecode Frame Rate"); Param_Info1C(Timecode_Frame_Rate && Timecode_Frame_Rate<TC_Frame_Rate_Table_Size-1, TC_Frame_Rate_Table[Timecode_Frame_Rate-1]);
+                Get_B8 (Start_Sample,                           "Start samples since midnight");
+                Get_B4 (Start_Residual,                         "Start Residual");
+                Get_B8 (Reference_Sample,                       "Reference samples since midnight");
+                Get_B4 (Reference_Residual,                     "Reference Residual");
+                break;
+            }
+        }
+        Skip_XX(End-Element_Offset,                             End-Element_Offset<=3?"Dword_Align":"(Unknown)");
+        Element_Offset=End;
+        Element_End0();
+    }
+    Element_End0();
+
+    Buffer_Offset=Buffer_Size;
+    return false;
+}
+
 //***************************************************************************
 // Buffer - Synchro
 //***************************************************************************
@@ -1009,7 +1280,11 @@ bool File_Dts::Synched_Test()
     if (!FrameSynchPoint_Test())
         return false; //Need more data
     if (!Synched)
+    {
+        if (Stream_Offset_Max!=-1 && File_Offset+Buffer_Offset==Stream_Offset_Max && File_Size!=-1)
+            Synched=true; // It is the file footer
         return true;
+    }
 
     //We continue
     return true;
@@ -1110,7 +1385,7 @@ void File_Dts::Data_Parse()
         Get_S3 (16+ExtraSize, HD_size,                          "ExtSSFsize"); HD_size++; Param_Info2(HD_size, " bytes");
         TESTELSE_SB_GET(StaticFieldsPresent,                    "StaticFieldsPresent");
             std::vector<int32u> ActiveExSSMasks;
-            Info_S1(2, RefClockCode,                            "RefClockCode"); Param_Info1(DTS_HD_RefClockCode[RefClockCode]);
+            Info_S1(2, RefClockCode,                            "RefClockCode"); Param_Info1C(RefClockCode<DTS_HD_RefClockCode_Size, DTS_HD_RefClockCode[RefClockCode]);
             Get_S1 (3, HD_ExSSFrameDurationCode,                "ExSSFrameDurationCode"); HD_ExSSFrameDurationCode++; Param_Info1(HD_ExSSFrameDurationCode);
             TEST_SB_SKIP(                                       "TimeStampFlag");
                 Skip_S5(36,                                     "TimeStamp");
@@ -1349,7 +1624,7 @@ void File_Dts::Core()
     //Parsing
     if (AuxiliaryData || ExtendedCoding)
     {
-        Extensions_Resynch();
+        Extensions_Resynch(true);
         Asset_Sizes.push_back(Element_Size-Element_Offset);
         Extensions();
     }
@@ -1363,7 +1638,12 @@ void File_Dts::Core()
 
             //No more need data
             if (!IsSub && Config->ParseSpeed<1.0)
-                Finish("DTS");
+            {
+                if (Stream_Offset_Max!=-1)
+                    GoTo(Stream_Offset_Max);
+                else
+                    Finish("DTS");
+            }
         }
     FILLING_END();
 }
@@ -1389,8 +1669,8 @@ void File_Dts::Extensions()
             int32u SyncWord;
             Get_B4(SyncWord,                                    "Sync Word");
             auto Index=DTS_Extension_Index_Get(SyncWord);
-            Element_Name(Index?Ztring().From_UTF8(DTS_Extension_Names[Index-1]):Ztring::ToZtring(SyncWord, 16));
-            switch (Index-1)
+            Element_Name(Index!=(size_t)-1?Ztring().From_UTF8(DTS_Extension_Names[Index]):Ztring::ToZtring(SyncWord, 16));
+            switch (Index)
             {
                 #define CASE(EXT) case Ext_##EXT : EXT(); break;
                 CASE(Padding4);
@@ -1403,7 +1683,7 @@ void File_Dts::Extensions()
                 CASE(Aux);
                 #undef CASE
                 default:
-                    Extensions_Resynch();
+                    Extensions_Resynch(false);
             }
             Element_End0();
         }
@@ -1445,7 +1725,7 @@ void File_Dts::Extensions()
 }
 
 //---------------------------------------------------------------------------
-void File_Dts::Extensions_Resynch()
+void File_Dts::Extensions_Resynch(bool Known)
 {
     if (Element_Size-Element_Offset<4)
         return;
@@ -1459,13 +1739,13 @@ void File_Dts::Extensions_Resynch()
     {
         auto SuncWord=BigEndian2int32u(Base+(size_t)Element_Offset);
         auto Index=DTS_Extension_Index_Get(SuncWord);
-        if (Index>1)
+        if (Index!=(size_t)-1 && Index>1)
         {
             bool IsNok=false;
             if (Element_Code)
             {
                 // HD
-                switch (Index-1)
+                switch (Index)
                 {
                     case Ext_X96:
                     case Ext_XLL:
@@ -1478,7 +1758,7 @@ void File_Dts::Extensions_Resynch()
             else
             {
                 // Core
-                switch (Index-1)
+                switch (Index)
                 {
                     case Ext_XCh:
                         IsNok=!ExtendedCoding || (ExtensionAudioDescriptor!=0 && ExtensionAudioDescriptor!=3);
@@ -1506,7 +1786,7 @@ void File_Dts::Extensions_Resynch()
         swap(Element_Offset, Element_Offset_Sav);
         if (Element_Size-Element_Offset_Sav<=3)
             Element_Offset_Sav=Element_Size;
-        Skip_XX(Element_Offset_Sav-Element_Offset,              "(Not parsed)");
+        Skip_XX(Element_Offset_Sav-Element_Offset,              Known?"(Not parsed)":"(Unknown)");
     }
 }
 
@@ -1548,11 +1828,11 @@ void File_Dts::Extensions_Padding()
 //---------------------------------------------------------------------------
 void File_Dts::LBR()
 {
-    Extensions_Resynch();
-
     FILLING_BEGIN();
         Presence.set(presence_Extended_LBR);
     FILLING_END();
+
+    Extensions_Resynch(true);
 }
 
 //---------------------------------------------------------------------------
@@ -1570,19 +1850,24 @@ void File_Dts::X96()
             return;
         auto CRC=Dts_CRC_CCIT_Compute(Buffer+Buffer_Offset+Element_Offset, HeaderSize-3);
         if (CRC)
+        {
+            Element_Info1("CRC NOK");
+            Extensions_Resynch(false);
             return;
+        }
     }
     else
     {
         // Core
         auto MaxSize=Element_Size-Element_Offset+3;
-        if (MaxSize<95)
-            return;
         int16u Begin;
         Peek_B2(Begin);
         int16u Size=Begin>>4;
-        if (Size<95 || Size!=MaxSize)
+        if (MaxSize<95 || Size<95 || Size!=MaxSize)
+        {
+            Extensions_Resynch(false);
             return;
+        }
         Skip_XX(Size-3,                                         "(Not parsed)");
     }
 
@@ -1590,7 +1875,7 @@ void File_Dts::X96()
         Presence.set(Element_Code?presence_Extended_X96:presence_Core_X96);
     FILLING_END();
 
-    Extensions_Resynch();
+    Extensions_Resynch(true);
 }
 
 //---------------------------------------------------------------------------
@@ -1624,7 +1909,15 @@ void File_Dts::XLL()
         return;
     auto CRC=Dts_CRC_CCIT_Compute(Buffer+Buffer_Offset+Element_Offset, HeaderSize-3);
     if (CRC)
+    {
+        Element_Info1("CRC NOK");
+        Extensions_Resynch(false);
         return;
+    }
+
+    FILLING_BEGIN();
+        Presence.set(presence_Extended_XLL);
+    FILLING_END();
 
     // Parsing
     int32u LLFrameSize;
@@ -1643,7 +1936,7 @@ void File_Dts::XLL()
     {
         BS_End();
         Element_End0();
-        Element_Offset=Element_Offset_Start;
+        Skip_XX(Element_Size-Element_Offset,                    "(Unknown)");
         return;
     }
     auto Element_Size_Save=Element_Size;
@@ -1679,7 +1972,8 @@ void File_Dts::XLL()
         auto CRC=Dts_CRC_CCIT_Compute(Buffer+Buffer_Offset+Element_Offset, ChSetHeaderSize+1);
         if (CRC)
         {
-            Element_Offset=Element_Offset_Start;
+            Skip_XX(Element_Size-Element_Offset,                "(Unknown)");
+            Element_Size=Element_Size_Save;
             return;
         }
         Element_Begin1("Channel Set");
@@ -1746,7 +2040,8 @@ void File_Dts::XLL()
             CRC=(CRC>>8)^CRC_CCIT_Table[((uint8_t)CRC)^*Buffer_Temp++];
         if (CRC)
         {
-            Element_Offset=Element_Offset_Start;
+            Skip_XX(Element_Size-Element_Offset,                "(Unknown)");
+            Element_Size=Element_Size_Save;
             return;
         }
         Count=(Buffer_Temp-(Buffer+Buffer_Offset+Element_Offset)-2)*8/Bits4SSize;
@@ -1754,13 +2049,15 @@ void File_Dts::XLL()
     auto SegmentSize_Size=2+(Count*Bits4SSize+7)/8;
     if (Element_Size-Element_Offset<SegmentSize_Size)
     {
-        Element_Offset=Element_Offset_Start;
+        Skip_XX(Element_Size-Element_Offset,                    "(Unknown)");
+        Element_Size=Element_Size_Save;
         return;
     }
     CRC=Dts_CRC_CCIT_Compute(Buffer+Buffer_Offset+Element_Offset, SegmentSize_Size);
     if (CRC)
     {
-        Element_Offset=Element_Offset_Start;
+        Skip_XX(Element_Size-Element_Offset,                    "(Unknown)");
+        Element_Size=Element_Size_Save;
         return;
     }
     Element_Begin1("NAVI");
@@ -1779,16 +2076,13 @@ void File_Dts::XLL()
 
     if (Element_Size-Element_Offset<Sizes_Total+Count)
     {
-        Element_Offset=Element_Offset_Start;
+        Skip_XX(Element_Size-Element_Offset,                    "(Unknown)");
+        Element_Size=Element_Size_Save;
         return;
     }
     Skip_XX(Sizes_Total,                                        "Segments");
     Skip_XX(Count,                                              "1 byte per segment?");
 
-    FILLING_BEGIN();
-        Presence.set(presence_Extended_XLL);
-    FILLING_END();
-
     Extensions_Padding();
     if (Element_Offset<Element_Size)
         Extensions2();
@@ -1809,7 +2103,15 @@ void File_Dts::XXCH()
         return;
     auto CRC=Dts_CRC_CCIT_Compute(Buffer+Buffer_Offset+Element_Offset, HeaderSize-3);
     if (CRC)
+    {
+        Element_Info1("CRC NOK");
+        Extensions_Resynch(false);
         return;
+    }
+
+    FILLING_BEGIN();
+        Presence.set(Element_Code?presence_Extended_XXCH:presence_Core_XXCH);
+    FILLING_END();
 
     // Parsing
     Element_Begin1("Header");
@@ -1833,7 +2135,7 @@ void File_Dts::XXCH()
         {
             BS_End();
             Element_End0();
-            Element_Offset=Element_Offset_Start;
+            Skip_XX(Element_Size-Element_Offset,                "(Unknown)");
             return;
         }
         ChSetFsizeXXCHs.push_back(ChSetFsizeXXCH);
@@ -1868,7 +2170,7 @@ void File_Dts::XXCH()
             auto CRC=Dts_CRC_CCIT_Compute(Buffer+Buffer_Offset+Element_Offset, XXCHChSetHeaderSize+1);
             if (CRC)
             {
-                Element_Offset=Element_Offset_Start;
+                Skip_XX(Element_Size-Element_Offset,            "(Unknown)");
                 return;
             }
             XXCHChSetHeaderSize-=2;
@@ -1889,10 +2191,6 @@ void File_Dts::XXCH()
         Element_End0();
     }
 
-    FILLING_BEGIN();
-        Presence.set(Element_Code?presence_Extended_XXCH:presence_Core_XXCH);
-    FILLING_END();
-
     Extensions_Padding();
 }
 
@@ -1909,6 +2207,10 @@ void File_Dts::XCh()
     if (Size<95 || (Size!=MaxSize && Size-1!=MaxSize)) // Is last item and manage legacy bitstreams
         return;
 
+    FILLING_BEGIN();
+        Presence.set(Element_Code?presence_Extended_XCh:presence_Core_XCh);
+    FILLING_END();
+
     //Parsing
     int16u XChFSIZE;
     int8u  AMODE;
@@ -1919,15 +2221,8 @@ void File_Dts::XCh()
     BS_End();
 
     FILLING_BEGIN();
-        if (Element_Code)
-        {
-            Presence.set(presence_Extended_XCh);
-        }
-        else
-        {
-            Presence.set(presence_Core_XCh);
+        if (!Element_Code)
             Core_XCh_AMODE=AMODE;
-        }
     FILLING_END();
 
     Extensions_Padding();
@@ -1947,7 +2242,15 @@ void File_Dts::XBR()
         return;
     auto CRC=Dts_CRC_CCIT_Compute(Buffer+Buffer_Offset+Element_Offset, HeaderSize-3);
     if (CRC)
+    {
+        Element_Info1("CRC NOK");
+        Extensions_Resynch(false);
         return;
+    }
+
+    FILLING_BEGIN();
+        Presence.set(presence_Extended_XBR);
+    FILLING_END();
 
     // Parsing
     Element_Begin1("Header");
@@ -1991,10 +2294,6 @@ void File_Dts::XBR()
         Element_End0();
     }
 
-    FILLING_BEGIN();
-        Presence.set(presence_Extended_XBR);
-    FILLING_END();
-
     Extensions_Padding();
 }
 
