@@ -477,6 +477,7 @@ enum general
     General_ISAN,
     General_BarCode,
     General_LCCN,
+    General_UMID,
     General_CatalogNumber,
     General_LabelCode,
     General_Owner,
@@ -553,6 +554,7 @@ enum video
     Video_HDR_Format_Profile,
     Video_HDR_Format_Level,
     Video_HDR_Format_Settings,
+    Video_HDR_Format_Compression,
     Video_HDR_Format_Compatibility,
     Video_Format_Settings,
     Video_Format_Settings_BVOP,
@@ -575,6 +577,8 @@ enum video
     Video_Format_Settings_GOP,
     Video_Format_Settings_PictureStructure,
     Video_Format_Settings_Wrapping,
+    Video_Format_Settings_SliceCount,
+    Video_Format_Settings_SliceCount_String,
     Video_InternetMediaType,
     Video_MuxingMode,
     Video_CodecID,
@@ -690,6 +694,12 @@ enum video
     Video_ActiveFormatDescription,
     Video_ActiveFormatDescription_String,
     Video_ActiveFormatDescription_MuxingMode,
+    Video_Active_Width,
+    Video_Active_Width_String,
+    Video_Active_Height,
+    Video_Active_Height_String,
+    Video_Active_DisplayAspectRatio,
+    Video_Active_DisplayAspectRatio_String,
     Video_Rotation,
     Video_Rotation_String,
     Video_FrameRate_Mode,
@@ -1721,12 +1731,20 @@ enum image
     Image_Format_Commercial_IfAny,
     Image_Format_Version,
     Image_Format_Profile,
+    Image_Format_Compression,
+    Image_Format_AdditionalFeatures,
+    Image_HDR_Format,
+    Image_HDR_Format_String,
+    Image_HDR_Format_Commercial,
+    Image_HDR_Format_Version,
+    Image_HDR_Format_Profile,
+    Image_HDR_Format_Level,
+    Image_HDR_Format_Settings,
+    Image_HDR_Format_Compatibility,
+    Image_Format_Settings,
     Image_Format_Settings_Endianness,
     Image_Format_Settings_Packing,
-    Image_Format_Compression,
-    Image_Format_Settings,
     Image_Format_Settings_Wrapping,
-    Image_Format_AdditionalFeatures,
     Image_InternetMediaType,
     Image_CodecID,
     Image_CodecID_String,
@@ -1759,6 +1777,12 @@ enum image
     Image_DisplayAspectRatio_String,
     Image_DisplayAspectRatio_Original,
     Image_DisplayAspectRatio_Original_String,
+    Image_Active_Width,
+    Image_Active_Width_String,
+    Image_Active_Height,
+    Image_Active_Height_String,
+    Image_Active_DisplayAspectRatio,
+    Image_Active_DisplayAspectRatio_String,
     Image_ColorSpace,
     Image_ChromaSubsampling,
     Image_Resolution,
@@ -1811,13 +1835,41 @@ enum image
     Image_Tagged_Date,
     Image_Encryption,
     Image_colour_description_present,
-    Image_colour_primaries,
-    Image_transfer_characteristics,
-    Image_matrix_coefficients,
+    Image_colour_description_present_Source,
     Image_colour_description_present_Original,
+    Image_colour_description_present_Original_Source,
+    Image_colour_range,
+    Image_colour_range_Source,
+    Image_colour_range_Original,
+    Image_colour_range_Original_Source,
+    Image_colour_primaries,
+    Image_colour_primaries_Source,
     Image_colour_primaries_Original,
+    Image_colour_primaries_Original_Source,
+    Image_transfer_characteristics,
+    Image_transfer_characteristics_Source,
     Image_transfer_characteristics_Original,
+    Image_transfer_characteristics_Original_Source,
+    Image_matrix_coefficients,
+    Image_matrix_coefficients_Source,
     Image_matrix_coefficients_Original,
+    Image_matrix_coefficients_Original_Source,
+    Image_MasteringDisplay_ColorPrimaries,
+    Image_MasteringDisplay_ColorPrimaries_Source,
+    Image_MasteringDisplay_ColorPrimaries_Original,
+    Image_MasteringDisplay_ColorPrimaries_Original_Source,
+    Image_MasteringDisplay_Luminance,
+    Image_MasteringDisplay_Luminance_Source,
+    Image_MasteringDisplay_Luminance_Original,
+    Image_MasteringDisplay_Luminance_Original_Source,
+    Image_MaxCLL,
+    Image_MaxCLL_Source,
+    Image_MaxCLL_Original,
+    Image_MaxCLL_Original_Source,
+    Image_MaxFALL,
+    Image_MaxFALL_Source,
+    Image_MaxFALL_Original,
+    Image_MaxFALL_Original_Source,
 };
 
 //---------------------------------------------------------------------------
@@ -1881,6 +1933,13 @@ enum menu
     Menu_Delay_Settings,
     Menu_Delay_DropFrame,
     Menu_Delay_Source,
+    Menu_FrameRate_Mode,
+    Menu_FrameRate_Mode_String,
+    Menu_FrameRate,
+    Menu_FrameRate_String,
+    Menu_FrameRate_Num,
+    Menu_FrameRate_Den,
+    Menu_FrameCount,
     Menu_List_StreamKind,
     Menu_List_StreamPos,
     Menu_List,
