@@ -850,6 +850,7 @@ public :
     void Get_ISO_8859_1(int64u Bytes, Ztring   &Info, const char* Name);
     void Get_ISO_8859_2(int64u Bytes, Ztring   &Info, const char* Name);
     void Get_ISO_8859_5(int64u Bytes, Ztring   &Info, const char* Name);
+    void Get_ISO_8859_9(int64u Bytes, Ztring   &Info, const char* Name);
     void Get_MacRoman(int64u Bytes, Ztring& Info, const char* Name);
     void Get_String (int64u Bytes, std::string &Info, const char* Name);
     void Get_UTF8   (int64u Bytes, Ztring      &Info, const char* Name);
@@ -860,6 +861,7 @@ public :
     void Peek_String(int64u Bytes, std::string &Info);
     void Skip_Local (int64u Bytes,                    const char* Name);
     void Skip_ISO_6937_2(int64u Bytes,                const char* Name);
+    void Skip_ISO_8859_1(int64u Bytes,                const char* Name);
     void Skip_String(int64u Bytes,                    const char* Name);
     void Skip_UTF8  (int64u Bytes,                    const char* Name);
     void Skip_UTF16B(int64u Bytes,                    const char* Name);
@@ -883,9 +885,9 @@ public :
     // Others, specialized
     //***************************************************************************
 
-    #if defined(MEDIAINFO_AV1_YES) || defined(MEDIAINFO_AVC_YES) || defined(MEDIAINFO_HEVC_YES) || defined(MEDIAINFO_MPEG4_YES) || defined(MEDIAINFO_MPEGTS_YES)
+    #if defined(MEDIAINFO_AV1_YES) || defined(MEDIAINFO_AVC_YES) || defined(MEDIAINFO_HEVC_YES) || defined(MEDIAINFO_MPEG4_YES) || defined(MEDIAINFO_MPEGTS_YES) || defined(MEDIAINFO_PNG_YES)
     void Get_MasteringDisplayColorVolume(Ztring& MasteringDisplay_ColorPrimaries, Ztring& MasteringDisplay_Luminance, bool FromAV1=false);
-    void Get_LightLevel(Ztring &MaxCLL, Ztring &MaxFALL);
+    void Get_LightLevel(Ztring &MaxCLL, Ztring &MaxFALL, int32u Divisor=1);
     #endif
     #if defined(MEDIAINFO_AV1_YES) || defined(MEDIAINFO_AVC_YES) || defined(MEDIAINFO_HEVC_YES) || defined(MEDIAINFO_MPEG4_YES) || defined(MEDIAINFO_MATROSKA_YES) || defined(MEDIAINFO_MXF_YES) || defined(MEDIAINFO_MPEGTS_YES)
     struct mastering_metadata_2086
@@ -1468,18 +1470,6 @@ public :
     bool MustSynchronize;
     bool CA_system_ID_MustSkipSlices;
     bool FillAllMergedStreams;
-    class streamidentity
-    {
-    public:
-        stream_t StreamKind;
-        size_t   StreamPos;
-
-        streamidentity(stream_t StreamKind_, size_t StreamPos_)
-            : StreamKind(StreamKind_)
-            , StreamPos(StreamPos_)
-        {}
-    };
-    std::vector<streamidentity> MergedStreams_Last;
 
     //Demux
     enum contenttype
