@@ -726,6 +726,7 @@ public :
     void Get_ISO_8859_1 (int64u Bytes, Ztring  &Info);
     void Get_ISO_8859_2 (int64u Bytes, Ztring  &Info);
     void Get_ISO_8859_5 (int64u Bytes, Ztring  &Info);
+    void Get_ISO_8859_9 (int64u Bytes, Ztring  &Info);
     void Get_MacRoman   (int64u Bytes, Ztring  &Info);
     void Get_String (int64u Bytes, std::string &Info);
     void Get_UTF8   (int64u Bytes, Ztring      &Info);
@@ -737,6 +738,7 @@ public :
     inline void Get_ISO_8859_1 (int64u Bytes, Ztring  &Info, const char*) {Get_ISO_8859_1(Bytes, Info);}
     inline void Get_ISO_8859_2 (int64u Bytes, Ztring  &Info, const char*) {Get_ISO_8859_2(Bytes, Info);}
     inline void Get_ISO_8859_5 (int64u Bytes, Ztring  &Info, const char*) {Get_ISO_8859_5(Bytes, Info);}
+    inline void Get_ISO_8859_9 (int64u Bytes, Ztring  &Info, const char*) {Get_ISO_8859_5(Bytes, Info);}
     inline void Get_MacRoman   (int64u Bytes, Ztring  &Info, const char*) {Get_MacRoman(Bytes, Info);}
     inline void Get_String (int64u Bytes, std::string &Info, const char*) {Get_String(Bytes, Info);}
     inline void Get_UTF8   (int64u Bytes, Ztring      &Info, const char*) {Get_UTF8(Bytes, Info);}
@@ -747,6 +749,7 @@ public :
     void Peek_String(int64u Bytes, std::string &Info);
     void Skip_Local (int64u Bytes,                    const char*) {if (Element_Offset+Bytes>Element_Size) {Trusted_IsNot(); return;} Element_Offset+=(size_t)Bytes;}
     void Skip_ISO_6937_2(int64u Bytes,                const char*) {if (Element_Offset+Bytes>Element_Size) {Trusted_IsNot(); return;} Element_Offset+=(size_t)Bytes;}
+    void Skip_ISO_8859_1(int64u Bytes,                const char*) {if (Element_Offset+Bytes>Element_Size) {Trusted_IsNot(); return;} Element_Offset+=(size_t)Bytes;}
     void Skip_String(int64u Bytes,                    const char*) {if (Element_Offset+Bytes>Element_Size) {Trusted_IsNot(); return;} Element_Offset+=(size_t)Bytes;}
     void Skip_UTF8  (int64u Bytes,                    const char*) {if (Element_Offset+Bytes>Element_Size) {Trusted_IsNot(); return;} Element_Offset+=(size_t)Bytes;}
     void Skip_UTF16B(int64u Bytes,                    const char*) {if (Element_Offset+Bytes>Element_Size) {Trusted_IsNot(); return;} Element_Offset+=(size_t)Bytes;}
@@ -772,9 +775,9 @@ public :
     // Others, specialized
     //***************************************************************************
 
-    #if defined(MEDIAINFO_AV1_YES) || defined(MEDIAINFO_AVC_YES) || defined(MEDIAINFO_HEVC_YES) || defined(MEDIAINFO_MPEG4_YES) || defined(MEDIAINFO_MPEGTS_YES)
+    #if defined(MEDIAINFO_AV1_YES) || defined(MEDIAINFO_AVC_YES) || defined(MEDIAINFO_HEVC_YES) || defined(MEDIAINFO_MPEG4_YES) || defined(MEDIAINFO_MPEGTS_YES) || defined(MEDIAINFO_PNG_YES)
     void Get_MasteringDisplayColorVolume(Ztring& MasteringDisplay_ColorPrimaries, Ztring& MasteringDisplay_Luminance, bool FromAV1=false);
-    void Get_LightLevel(Ztring &MaxCLL, Ztring &MaxFALL);
+    void Get_LightLevel(Ztring &MaxCLL, Ztring &MaxFALL, int32u Divisor=1);
     #endif
     #if defined(MEDIAINFO_AV1_YES) || defined(MEDIAINFO_AVC_YES) || defined(MEDIAINFO_HEVC_YES) || defined(MEDIAINFO_MPEG4_YES) || defined(MEDIAINFO_MATROSKA_YES) || defined(MEDIAINFO_MXF_YES) || defined(MEDIAINFO_MPEGTS_YES)
     struct mastering_metadata_2086
@@ -1390,18 +1393,6 @@ public :
     bool MustSynchronize;
     bool CA_system_ID_MustSkipSlices;
     bool FillAllMergedStreams;
-    class streamidentity
-    {
-    public:
-        stream_t StreamKind;
-        size_t   StreamPos;
-
-        streamidentity(stream_t StreamKind_, size_t StreamPos_)
-            : StreamKind(StreamKind_)
-            , StreamPos(StreamPos_)
-        {}
-    };
-    std::vector<streamidentity> MergedStreams_Last;
 
     //Demux
     enum contenttype
