@@ -53,6 +53,7 @@ enum basicformat
     enum config_flags1
     {
         Flags_Cover_Data_base64,
+        Flags_Enable_FFmpeg,
     };
 #else //MEDIAINFO_COMPRESS
     #define MEDIAINFO_FLAG1 0
@@ -71,6 +72,14 @@ enum basicformat
     #define MEDIAINFO_FLAGX 0
 #endif //MEDIAINFO_COMPRESS
 
+enum class display_if
+{
+    Never,
+    Needed,
+    Supported,
+    Always,
+};
+
 //***************************************************************************
 // Class MediaInfo_Config
 //***************************************************************************
@@ -210,6 +219,10 @@ public :
           Ztring    Cover_Data_Set (const Ztring &NewValue);
           Ztring    Cover_Data_Get ();
           #endif //MEDIAINFO_ADVANCED
+          #if MEDIAINFO_ADVANCED && defined(MEDIAINFO_FILE_YES)
+          Ztring    Enable_FFmpeg_Set (bool NewValue);
+          bool      Enable_FFmpeg_Get ();
+          #endif //MEDIAINFO_ADVANCED && defined(MEDIAINFO_FILE_YES
           #if MEDIAINFO_COMPRESS
           Ztring    Inform_Compress_Set (const Ztring &NewInform);
           Ztring    Inform_Compress_Get ();
@@ -236,7 +249,7 @@ public :
     const Ztring   &Iso639_1_Get (const Ztring &Value);
     const Ztring   &Iso639_2_Get (const Ztring &Value);
     const Ztring    Iso639_Find (const Ztring &Value);
-    const Ztring    Iso639_Translate (const Ztring Value);
+    const Ztring    Iso639_Translate (const Ztring &Value);
 
     const Ztring   &Info_Get (stream_t KindOfStream, const Ztring &Value, info_t KindOfInfo=Info_Text);
     const Ztring   &Info_Get (stream_t KindOfStream, size_t Pos, info_t KindOfInfo=Info_Text);
@@ -324,6 +337,10 @@ public :
     #if MEDIAINFO_ADVANCED
           void        Collection_Trigger_Set (const Ztring& Value);
           int64s      Collection_Trigger_Get();
+          Ztring      Collection_Display_Set(const Ztring& Value);
+          display_if  Collection_Display_Get();
+    #else //MEDIAINFO_ADVANCED
+          display_if  Collection_Display_Get() {return display_if::Needed;}
     #endif //MEDIAINFO_ADVANCED
 
     void            CustomMapping_Set (const Ztring &Value);
@@ -511,6 +528,7 @@ private :
 
     #if MEDIAINFO_ADVANCED
         int64s      Collection_Trigger;
+        display_if  Collection_Display;
     #endif //MEDIAINFO_ADVANCED
 
     std::map<Ztring, std::map<Ztring, Ztring> > CustomMapping;
