@@ -513,7 +513,7 @@ struct MediaInfo_Event_DvDif_Analysis_Frame_1
     MEDIAINFO_EVENT_GENERIC
     MediaInfo_int32u        TimeCode;
     MediaInfo_int32u        RecordedDateTime1;
-    MediaInfo_int16u        RecordedDateTime2;
+    MediaInfo_int16u        RecordedDateTime2Buggy;
     MediaInfo_int8u         Arb;
     MediaInfo_int8u         Verbosity;
     const char*             Errors;
@@ -523,6 +523,12 @@ struct MediaInfo_Event_DvDif_Analysis_Frame_1
     size_t*                 Audio_Data_Errors;
     MediaInfo_int32u        Captions_Errors; // bit 0 = parity issue
     MediaInfo_int32u        Coherency_Flags; // bit 0 = no pack sub, bit 1 = no pack vid, bit 2 = no pack aud, bit 3 = no data vid, bit 4 = no data aud, bit 5 = no vid source/control, bit 6 = no aud source/control
+    MediaInfo_int16u        RecordedDateTime2;
+    size_t                  BlockStatus_Count;
+    const MediaInfo_int8u*  BlockStatus;
+    MediaInfo_int32u        AbstBf;
+    MediaInfo_int32u        MoreFlags;
+    const MediaInfo_int8u*  MoreData;
 };
 
 /*-------------------------------------------------------------------------*/
@@ -685,6 +691,12 @@ struct MediaInfo_Event_DvDif_Change_0
 
 #define MediaInfo_Parser_MiXml          0x6C
 
+/***************************************************************************/
+/* NSV                                                                     */
+/***************************************************************************/
+
+#define MediaInfo_Parser_Nsv            0x6D
+
 /***************************************************************************/
 /* MPEG Video                                                              */
 /***************************************************************************/
