@@ -32,9 +32,15 @@
 #if defined(MEDIAINFO_GXF_YES)
     #include "MediaInfo/Multiple/File_Umf.h"
 #endif
+#if defined(MEDIAINFO_AVC_YES)
+    #include "MediaInfo/Video/File_Avc.h"
+#endif
 #if defined(MEDIAINFO_MPEGV_YES)
     #include "MediaInfo/Video/File_Mpegv.h"
 #endif
+#if defined(MEDIAINFO_VC3_YES)
+    #include "MediaInfo/Video/File_Vc3.h"
+#endif
 #if defined(MEDIAINFO_AC3_YES)
     #include "MediaInfo/Audio/File_Ac3.h"
 #endif
@@ -112,6 +118,9 @@ static const char* Gxf_MediaTypes(int8u Type)
         case 23 : return "MPEG-1 Video"; //625 lines
         case 24 : return "SMPTE 12M"; //HD
         case 25 : return "DV"; //DVCPRO HD
+        case 26 : return "AVC";
+        case 29 : return "AVC";
+        case 30 : return "VC-3";
         default : return "";
     }
 }
@@ -142,6 +151,9 @@ static stream_t Gxf_MediaTypes_StreamKind(int8u Type)
         case 23 : return Stream_Video;
         case 24 : return Stream_Max;
         case 25 : return Stream_Video;
+        case 26 : return Stream_Video;
+        case 29 : return Stream_Video;
+        case 30 : return Stream_Video;
         default : return Stream_Max;
     }
 }
@@ -790,8 +802,10 @@ void File_Gxf::Header_Parse()
         {
             if (PacketType==0xBF) //media
             {
+	#if MEDIAINFO_NEXTPACKET
                 if (Config->NextPacket_Get() && Config->Event_CallBackFunction_IsSet())
                     Config->Demux_EventWasSent=true; //First set is to indicate the user that header is parsed
+	#endif
                 Demux_HeaderParsed=true;
             }
         }
@@ -1079,6 +1093,27 @@ void File_Gxf::map()
                                         #endif //MEDIAINFO_RIFF_YES
                                     }
                                     break;
+                        case 26 :
+                        case 29 :   //AVC
+                                    {
+                                        File__Analyze* Parser=new File_Avc();
+                                        Open_Buffer_Init(Parser);
+                                        Streams[TrackID].Parsers.push_back(Parser);
+
+                                        Parsers_Count++;
+                                        Streams[TrackID].Searching_Payload=true;
+                                    }
+                                    break;
+                        case 30 :   //VC-3
+                                    {
+                                        File__Analyze* Parser=new File_Vc3();
+                                        Open_Buffer_Init(Parser);
+                                        Streams[TrackID].Parsers.push_back(Parser);
+
+                                        Parsers_Count++;
+                                        Streams[TrackID].Searching_Payload=true;
+                                    }
+                                    break;
                         default :   ;
                     }
 
@@ -1254,14 +1289,14 @@ void File_Gxf::map()
             //Test on TimeCode
             if (TimeCode_Parsed && !Invalid)
             {
-                std::map<int8u, tc>::iterator TimeCode=TimeCodes.find(TrackID);
-                if (TimeCode==TimeCodes.end() || TimeCode->second.Milliseconds==(int64u)-1)
+                std::map<int8u, tc>::iterator TimeCode_Item=TimeCodes.find(TrackID);
+                if (TimeCode_Item==TimeCodes.end() || TimeCode_Item->second.Milliseconds==(int64u)-1)
                 {
                     float64 FrameRate=Gxf_FrameRate(Streams[TrackID].FrameRate_Code);
                     TimeCodes[TrackID].Milliseconds=Hours  *60*60*1000
                                                    +Minutes   *60*1000
                                                    +Seconds      *1000;
-                    TimeCodes[TrackID].String= MediaInfoLib::TimeCode(Hours, Minutes, Seconds, Fields/2, 0, DropFrame, false, Fields%2).ToString();
+                    TimeCodes[TrackID].String=TimeCode(Hours, Minutes, Seconds, Fields/2, 99, TimeCode::DropFrame(DropFrame).Field(Fields%2)).ToString();
 
                     if (!FrameRate)
                     {
