@@ -525,6 +525,7 @@ size_t File_Lxf::Read_Buffer_Seek (size_t Method, int64u Value, int64u)
                         float64 TimeStamp=((float64)Value)/FrameRate;
                         Value=float64_int64s(TimeStamp*1000000000); // In nanoseconds
                     }
+                    return 1;
         case 2  :   //Timestamp
                     {
                     if (Value!=(int64u)-1)
@@ -910,7 +911,7 @@ void File_Lxf::Header()
 
     Info_General_StreamSize=0x48+Element_Size;
 
-    #if MEDIAINFO_DEMUX
+    #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
         if (Config->NextPacket_Get() && Config->Event_CallBackFunction_IsSet())
             Config->Demux_EventWasSent=true; //First set is to indicate the user that header is parsed
     #endif //MEDIAINFO_DEMUX
