@@ -142,6 +142,7 @@ private :
     File_DolbyAudioMetadata* DolbyAudioMetadata;
     #if defined(MEDIAINFO_ADM_YES)
     File_Adm* Adm;
+    File_Adm* Adm_chna;
     #endif
     int64u WAVE_data_Size;  //RF64 WAVE_data real chunk size
     int64u WAVE_fact_samplesCount;  //RF64 WAVE_fact real samplesCount
@@ -163,6 +164,7 @@ private :
     int32u SamplesPerSec;   //For bext
     int16u BitsPerSample;   //For PCM only
     int8u  stream_Count;    //How many stream we have to parse
+    int8u  Format_Settings[2];
     bool   rec__Present;    //True if synchro element is present
     bool   NeedOldIndex;
     bool   IsBigEndian;
@@ -180,6 +182,7 @@ private :
         Kind_Wave,
         Kind_Aiff,
         Kind_Rmp3,
+        Kind_Axml,
     };
     kind Kind;
     #if defined(MEDIAINFO_GXF_YES)
@@ -317,6 +320,7 @@ private :
     void WAVE_adtl_ltxt();
     void WAVE_adtl_note();
     void WAVE_axml ();
+    void WAVE_axml_Continue ();
     void WAVE_bext ();
     void WAVE_bxml () {WAVE_axml();}
     void WAVE_chna();
