@@ -11,6 +11,7 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/File__Analyze.h"
+#include "MediaInfo/TimeCode.h"
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -29,6 +30,7 @@ public :
     bool   MustParse_VPS_SPS_PPS;
     bool   MustParse_VPS_SPS_PPS_FromMatroska;
     bool   MustParse_VPS_SPS_PPS_FromFlv;
+    bool   MustParse_VPS_SPS_PPS_FromLhvc;
     bool   SizedBlocks;
     size_t SizedBlocks_FileThenStream;
 
@@ -40,6 +42,35 @@ private :
     File_Hevc(const File_Hevc &File_Hevc); //No copy
     File_Hevc &operator =(const File_Hevc &); //No copy
 
+    struct profile_tier_level_struct {
+        int8u   profile_space;
+        int8u   profile_idc;
+        int8u   level_idc;
+        bool    tier_flag;
+        bool    general_progressive_source_flag;
+        bool    general_interlaced_source_flag;
+        bool    general_frame_only_constraint_flag;
+        bool    general_max_8bit_constraint_flag;
+        bool    general_max_10bit_constraint_flag;
+        bool    general_max_12bit_constraint_flag;
+        bool    general_max_14bit_constraint_flag;
+
+        profile_tier_level_struct& Clear()
+        {
+            profile_space = -1;
+            profile_idc = -1;
+            level_idc = -1;
+            tier_flag = true;
+            general_progressive_source_flag = true;
+            general_interlaced_source_flag = true;
+            general_frame_only_constraint_flag = true;
+            general_max_8bit_constraint_flag = true;
+            general_max_10bit_constraint_flag = true;
+            general_max_12bit_constraint_flag = true;
+            general_max_14bit_constraint_flag = true;
+            return *this;
+        }
+    };
 
     //Structures - video_parameter_set
     struct video_parameter_set_struct
@@ -48,15 +79,19 @@ private :
         int8u*  AnnexB_Buffer;
         size_t  AnnexB_Buffer_Size;
         #endif //MEDIAINFO_DEMUX
+        vector<profile_tier_level_struct> profile_tier_level_info_layers;
+        vector<int16u> view_id_val;
         int8u   vps_max_sub_layers_minus1;
 
         //Constructor/Destructor
-        video_parameter_set_struct(int8u vps_max_sub_layers_minus1_)
+        video_parameter_set_struct(const vector<profile_tier_level_struct>& profile_tier_level_info_layers_, int8u vps_max_sub_layers_minus1_, vector<int16u> view_id_val_)
         :
             #if MEDIAINFO_DEMUX
             AnnexB_Buffer(NULL),
             AnnexB_Buffer_Size(0),
             #endif //MEDIAINFO_DEMUX
+            profile_tier_level_info_layers(profile_tier_level_info_layers_),
+            view_id_val(view_id_val_),
             vps_max_sub_layers_minus1(vps_max_sub_layers_minus1_)
         {
         }
@@ -196,15 +231,13 @@ private :
             vui_parameters_struct(const vui_parameters_struct &);
             vui_parameters_struct();
         };
+        int32u  nuh_layer_id;
         vui_parameters_struct* vui_parameters;
         #if MEDIAINFO_DEMUX
         int8u*  AnnexB_Buffer;
         size_t  AnnexB_Buffer_Size;
         #endif //MEDIAINFO_DEMUX
-        int32u  profile_space;
-        bool    tier_flag;
-        int32u  profile_idc;
-        int32u  level_idc;
+        profile_tier_level_struct profile_tier_level_info;
         int32u  pic_width_in_luma_samples;
         int32u  pic_height_in_luma_samples;
         int32u  conf_win_left_offset;
@@ -218,10 +251,6 @@ private :
         int8u   bit_depth_luma_minus8;
         int8u   bit_depth_chroma_minus8;
         int8u   sps_max_num_reorder_pics;
-        bool    general_progressive_source_flag;
-        bool    general_interlaced_source_flag;
-        bool    general_frame_only_constraint_flag;
-        bool    general_max_8bit_constraint_flag;
 
         //Computed value
         bool    NalHrdBpPresentFlag() {return vui_parameters && vui_parameters->NAL;}
@@ -230,17 +259,15 @@ private :
         int8u   ChromaArrayType() {return separate_colour_plane_flag?0:chroma_format_idc;}
 
         //Constructor/Destructor
-        seq_parameter_set_struct(vui_parameters_struct* vui_parameters_, int32u profile_space_, bool tier_flag_, int32u profile_idc_, int32u level_idc_, int32u pic_width_in_luma_samples_, int32u pic_height_in_luma_samples_, int32u conf_win_left_offset_, int32u conf_win_right_offset_, int32u conf_win_top_offset_, int32u conf_win_bottom_offset_, int8u video_parameter_set_id_, int8u chroma_format_idc_, bool separate_colour_plane_flag_, int8u log2_max_pic_order_cnt_lsb_minus4_, int8u bit_depth_luma_minus8_, int8u bit_depth_chroma_minus8_, int8u sps_max_num_reorder_pics_, bool general_progressive_source_flag_, bool general_interlaced_source_flag_, bool general_frame_only_constraint_flag_, bool general_max_8bit_constraint_flag_)
+        seq_parameter_set_struct(int32u nuh_layer_id_, vui_parameters_struct* vui_parameters_, const profile_tier_level_struct& profile_tier_level_info_, int32u pic_width_in_luma_samples_, int32u pic_height_in_luma_samples_, int32u conf_win_left_offset_, int32u conf_win_right_offset_, int32u conf_win_top_offset_, int32u conf_win_bottom_offset_, int8u video_parameter_set_id_, int8u chroma_format_idc_, bool separate_colour_plane_flag_, int8u log2_max_pic_order_cnt_lsb_minus4_, int8u bit_depth_luma_minus8_, int8u bit_depth_chroma_minus8_, int8u sps_max_num_reorder_pics_)
             :
+            nuh_layer_id(nuh_layer_id_),
             vui_parameters(vui_parameters_),
             #if MEDIAINFO_DEMUX
             AnnexB_Buffer(NULL),
             AnnexB_Buffer_Size(0),
             #endif //MEDIAINFO_DEMUX
-            profile_space(profile_space_),
-            tier_flag(tier_flag_),
-            profile_idc(profile_idc_),
-            level_idc(level_idc_),
+            profile_tier_level_info(profile_tier_level_info_),
             pic_width_in_luma_samples(pic_width_in_luma_samples_),
             pic_height_in_luma_samples(pic_height_in_luma_samples_),
             conf_win_left_offset(conf_win_left_offset_),
@@ -253,11 +280,7 @@ private :
             log2_max_pic_order_cnt_lsb_minus4(log2_max_pic_order_cnt_lsb_minus4_),
             bit_depth_luma_minus8(bit_depth_luma_minus8_),
             bit_depth_chroma_minus8(bit_depth_chroma_minus8_),
-            sps_max_num_reorder_pics(sps_max_num_reorder_pics_),
-            general_progressive_source_flag(general_progressive_source_flag_),
-            general_interlaced_source_flag(general_interlaced_source_flag_),
-            general_frame_only_constraint_flag(general_frame_only_constraint_flag_),
-            general_max_8bit_constraint_flag(general_max_8bit_constraint_flag_)
+            sps_max_num_reorder_pics(sps_max_num_reorder_pics_)
         {
         }
 
@@ -320,6 +343,8 @@ private :
 
     //Streams management
     void Streams_Fill();
+    void Streams_Fill_Profile(const profile_tier_level_struct& p);
+    void Streams_Fill(vector<video_parameter_set_struct*>::iterator video_parameter_set_Item);
     void Streams_Fill(vector<seq_parameter_set_struct*>::iterator seq_parameter_set_Item);
     void Streams_Finish();
 
@@ -349,7 +374,7 @@ private :
     //Elements
     void slice_segment_layer();
     void video_parameter_set();
-    void video_parameter_sets_creating_data(int8u vps_video_parameter_set_id, int8u vps_max_sub_layers_minus1);
+    void video_parameter_sets_creating_data(int8u vps_video_parameter_set_id, const vector<profile_tier_level_struct>& profile_tier_level_info_layers, int8u vps_max_sub_layers_minus1, const vector<int16u>& view_id_val);
     void seq_parameter_set();
     void pic_parameter_set();
     void access_unit_delimiter();
@@ -364,9 +389,11 @@ private :
     void sei_message_user_data_registered_itu_t_t35();
     void sei_message_user_data_registered_itu_t_t35_B5();
     void sei_message_user_data_registered_itu_t_t35_B5_0031();
+    void sei_message_user_data_registered_itu_t_t35_B5_0031_DTG1();
     void sei_message_user_data_registered_itu_t_t35_B5_0031_GA94();
     void sei_message_user_data_registered_itu_t_t35_B5_0031_GA94_03();
     void sei_message_user_data_registered_itu_t_t35_B5_0031_GA94_03_Delayed(int32u seq_parameter_set_id);
+    void sei_message_user_data_registered_itu_t_t35_B5_0031_GA94_09();
     void sei_message_user_data_registered_itu_t_t35_B5_003A();
     void sei_message_user_data_registered_itu_t_t35_B5_003A_00();
     void sei_message_user_data_registered_itu_t_t35_B5_003A_02();
@@ -381,14 +408,16 @@ private :
     void sei_message_user_data_unregistered_x265(int32u payloadSize);
     void sei_message_recovery_point();
     void sei_message_active_parameter_sets();
+    void sei_time_code();
     void sei_message_decoded_picture_hash(int32u payloadSize);
     void sei_message_mastering_display_colour_volume();
     void sei_message_light_level();
     void sei_alternative_transfer_characteristics();
+    void three_dimensional_reference_displays_info(int32u payloadSize);
 
     //Packets - SubElements
     void slice_segment_header();
-    void profile_tier_level(int8u maxNumSubLayersMinus1);
+    void profile_tier_level(profile_tier_level_struct& p, bool profilePresentFlag, int8u maxNumSubLayersMinus1);
     void short_term_ref_pic_sets(int8u num_short_term_ref_pic_sets);
     void vui_parameters(std::vector<video_parameter_set_struct*>::iterator video_parameter_set_Item, seq_parameter_set_struct::vui_parameters_struct* &vui_parameters_Item);
     void hrd_parameters(bool commonInfPresentFlag, int8u maxNumSubLayersMinus1, seq_parameter_set_struct::vui_parameters_struct::xxl_common* &xxL_Common, seq_parameter_set_struct::vui_parameters_struct::xxl* &NAL, seq_parameter_set_struct::vui_parameters_struct::xxl* &VCL);
@@ -450,6 +479,9 @@ private :
         bool                            GA94_03_IsPresent;
     #endif //defined(MEDIAINFO_DTVCCTRANSPORT_YES)
 
+    //Misc
+    TimeCode                            TC_Current;
+
     //Replacement of File__Analyze buffer
     const int8u*                        Buffer_ToSave;
     size_t                              Buffer_Size_ToSave;
@@ -476,9 +508,10 @@ private :
     Ztring                              Encoded_Library_Settings;
     enum hdr_format
     {
+        HdrFormat_SmpteSt209410,
+        HdrFormat_SmpteSt209440,
         HdrFormat_EtsiTs103433,
         HdrFormat_HdrVivid,
-        HdrFormat_SmpteSt209440,
         HdrFormat_SmpteSt2086,
         HdrFormat_Max,
     };
@@ -493,15 +526,7 @@ private :
     Ztring  maximum_content_light_level;
     Ztring  maximum_frame_average_light_level;
     int8u   nuh_layer_id;
-    int8u   profile_space;
-    int8u   profile_idc;
-    int8u   level_idc;
     int8u   preferred_transfer_characteristics;
-    bool    tier_flag;
-    bool    general_progressive_source_flag;
-    bool    general_interlaced_source_flag;
-    bool    general_frame_only_constraint_flag;
-    bool    general_max_8bit_constraint_flag;
     bool    RapPicFlag;
     bool    first_slice_segment_in_pic_flag;
 };
